@@ -71,33 +71,37 @@ __all__ = (
 
 class DescribeResourceCollectionHealthPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeResourceCollectionHealth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.DescribeResourceCollectionHealth)
+    [Paginator.DescribeResourceCollectionHealth documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.DescribeResourceCollectionHealth)
     """
 
     def paginate(
-        self, ResourceCollectionType: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self,
+        ResourceCollectionType: Literal["AWS_CLOUD_FORMATION"],
+        PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeResourceCollectionHealthResponseTypeDef]:
         """
-        [DescribeResourceCollectionHealth.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.DescribeResourceCollectionHealth.paginate)
+        [DescribeResourceCollectionHealth.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.DescribeResourceCollectionHealth.paginate)
         """
 
 
 class GetResourceCollectionPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceCollection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.GetResourceCollection)
+    [Paginator.GetResourceCollection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.GetResourceCollection)
     """
 
     def paginate(
-        self, ResourceCollectionType: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self,
+        ResourceCollectionType: Literal["AWS_CLOUD_FORMATION"],
+        PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceCollectionResponseTypeDef]:
         """
-        [GetResourceCollection.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.GetResourceCollection.paginate)
+        [GetResourceCollection.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.GetResourceCollection.paginate)
         """
 
 
 class ListAnomaliesForInsightPaginator(Boto3Paginator):
     """
-    [Paginator.ListAnomaliesForInsight documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListAnomaliesForInsight)
+    [Paginator.ListAnomaliesForInsight documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListAnomaliesForInsight)
     """
 
     def paginate(
@@ -107,26 +111,26 @@ class ListAnomaliesForInsightPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAnomaliesForInsightResponseTypeDef]:
         """
-        [ListAnomaliesForInsight.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListAnomaliesForInsight.paginate)
+        [ListAnomaliesForInsight.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListAnomaliesForInsight.paginate)
         """
 
 
 class ListEventsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListEvents)
+    [Paginator.ListEvents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListEvents)
     """
 
     def paginate(
         self, Filters: ListEventsFiltersTypeDef, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListEventsResponseTypeDef]:
         """
-        [ListEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListEvents.paginate)
+        [ListEvents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListEvents.paginate)
         """
 
 
 class ListInsightsPaginator(Boto3Paginator):
     """
-    [Paginator.ListInsights documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListInsights)
+    [Paginator.ListInsights documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListInsights)
     """
 
     def paginate(
@@ -135,39 +139,39 @@ class ListInsightsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListInsightsResponseTypeDef]:
         """
-        [ListInsights.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListInsights.paginate)
+        [ListInsights.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListInsights.paginate)
         """
 
 
 class ListNotificationChannelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListNotificationChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListNotificationChannels)
+    [Paginator.ListNotificationChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListNotificationChannels)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListNotificationChannelsResponseTypeDef]:
         """
-        [ListNotificationChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListNotificationChannels.paginate)
+        [ListNotificationChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListNotificationChannels.paginate)
         """
 
 
 class ListRecommendationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRecommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListRecommendations)
+    [Paginator.ListRecommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListRecommendations)
     """
 
     def paginate(
         self, InsightId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListRecommendationsResponseTypeDef]:
         """
-        [ListRecommendations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.ListRecommendations.paginate)
+        [ListRecommendations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.ListRecommendations.paginate)
         """
 
 
 class SearchInsightsPaginator(Boto3Paginator):
     """
-    [Paginator.SearchInsights documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.SearchInsights)
+    [Paginator.SearchInsights documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.SearchInsights)
     """
 
     def paginate(
@@ -178,5 +182,5 @@ class SearchInsightsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[SearchInsightsResponseTypeDef]:
         """
-        [SearchInsights.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.34/reference/services/devops-guru.html#DevopsGuru.Paginator.SearchInsights.paginate)
+        [SearchInsights.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.37/reference/services/devops-guru.html#DevopsGuru.Paginator.SearchInsights.paginate)
         """
